@@ -1,7 +1,7 @@
 #![forbid(unsafe_code)]
 #![deny(
     missing_copy_implementations,
-    missing_crate_level_docs,
+    rustdoc::missing_crate_level_docs,
     missing_debug_implementations,
     missing_docs,
     nonstandard_style,
